/* Copyright(C) 2017-2024, HJD (https://github.com/hjdhjd). All rights reserved.
 *
 * protect-ffmpeg-exec.ts: Execute arbitrary FFmpeg commands and return the results.
 *
 */
import { FfmpegProcess } from "./protect-ffmpeg.js";
export class FfmpegExec extends FfmpegProcess {
    constructor(protectCamera, commandLineArgs) {
        // Initialize our parent.
        super(protectCamera, commandLineArgs);
    }
    // Run the FFmpeg process and return the result.
    exec(stdinData) {
        return new Promise((resolve) => {
            this.start();
            if (this.process === null) {
                this.log.error("Unable to execute command.");
                return null;
            }
            // Write data to stdin and close
            if (stdinData) {
                this.process.stdin.end(stdinData);
            }
            const stderr = [];
            const stdout = [];
            // Read standard output and standard error into buffers.
            this.process.stderr.on("data", (chunk) => stderr.push(chunk));
            this.process.stdout.on("data", (chunk) => stdout.push(chunk));
            // We prepend this listener to ensure we can properly cleanup after ourselves.
            this.process.prependOnceListener("exit", () => {
                // Trigger our process cleanup activities.
                this.stop();
            });
            // Return when process is done.
            this.process.once("exit", (exitCode) => {
                // Return the output and results.
                resolve({
                    exitCode,
                    stderr: Buffer.concat(stderr),
                    stdout: Buffer.concat(stdout)
                });
            });
        });
    }
}
//# sourceMappingURL=protect-ffmpeg-exec.js.map